<!--
  Transforms openmath to gap syntax.
-->
<xsl:transform version='1.0'
  xmlns:xsl='http://www.w3.org/1999/XSL/Transform'
  xmlns:exslt='http://exslt.org/common'
  xmlns:om='http://www.openmath.org/OpenMath'
>

  <!-- application of a variable -->
  <xsl:template match='om:OMA[*[1][self::om:OMV]]'>
    <xsl:apply-templates select='*[1]'/>
    <xsl:text>(</xsl:text>
      <xsl:for-each select='*[position()>1]'>
        <xsl:if test='position()>1'>
          <xsl:text>,</xsl:text>
        </xsl:if>
        <xsl:apply-templates select='.'/>
      </xsl:for-each>
    <xsl:text>)</xsl:text>
  </xsl:template>
  
  <!-- application of a symbol -->
  <xsl:template match='om:OMA[*[1][self::om:OMS]]'>
  
    <!-- fetch operator details -->
    <xsl:variable name='cd' select='*[1]/@cd'/>
    <xsl:variable name='name' select='*[1]/@name'/>
    <xsl:variable 
      name='symbol' 
      select='exslt:node-set($symbols)/cd[@name=$cd]/symbol[@name=$name]'
    />
  
    <!-- write prefix symbol -->
    <xsl:if test='$symbol/@appearance = "prefix"'>
      <xsl:value-of select='$symbol/@text'/>
    </xsl:if>
    
    <!-- write arguments -->
    <xsl:text>(</xsl:text>
      <xsl:for-each select='*[position()>1]'>
        <xsl:if test='position()>1'>
        
          <!-- write infix symbol -->
          <xsl:choose>
            <xsl:when test='$symbol/@appearance = "infix"'>
              <xsl:value-of select='$symbol/@text'/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>,</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
          
        </xsl:if>
        <xsl:apply-templates select='.'/>
      </xsl:for-each>
    <xsl:text>)</xsl:text>
    
    <!-- write postfix symbol -->
    <xsl:if test='$symbol/@appearance = "postfix"'>
      <xsl:value-of select='$symbol/@text'/>
    </xsl:if>
    
  </xsl:template>

  <!-- application of a lambda function -->
  <xsl:template 
    match='om:OMA[*[1][self::om:OMBIND[*[1][
      self::om:OMS[@cd="fns1" and @name="lambda"]]]]]'
  >
    <xsl:text>(</xsl:text>
    <xsl:apply-templates select='om:OMBIND'/>
    <xsl:text>)(</xsl:text>
    <xsl:for-each select='*[position() > 1]'>
      <xsl:if test='position() > 1'>
	<xsl:text>, </xsl:text>
      </xsl:if>
      <xsl:apply-templates select='.'/>
    </xsl:for-each>
    <xsl:text>)</xsl:text>
  </xsl:template>
 
</xsl:transform>
