<!--
  Stores information about openmath symbols in the $symbols variable.
-->
<xsl:transform version='1.0' xmlns:xsl='http://www.w3.org/1999/XSL/Transform'>

  <xsl:variable name='symbols'>
     
    <!--
      MathML CD Group from http://www.openmath.org/cdgroups/mathml.html
      version 2, contains the CDs: alg1 arith1 bigfloat1 calculus1 complex1
      fns1 integer1 interval1 linalg1 linalg2 limit1 list1 logic1 mathmltypes
      minmax1 multiset1 nums1 piece1 quant1 relation1 setname1 rounding1 set1
      s_data1 s_dist1 transc1 veccalc1 altenc 
    -->
    <cd name='alg1' version='3'>
      <symbol name='one'  text='1'/>
      <symbol name='zero' text='0'/>
    </cd>
    
    <cd name='arith1' version='3'>
      <symbol name='abs'         appearance='prefix' text='Math.abs' />
      <symbol name='divide'      appearance='infix'  text='/'        />
      <symbol name='gcd'/>
      <symbol name='lcm'/>
      <symbol name='minus'       appearance='infix'  text='-'        />
      <symbol name='plus'        appearance='infix'  text='+'        />
      <symbol name='power'       appearance='prefix' text='Math.pow' />
      <symbol name='product'/>
      <symbol name='root'        implementation='xsl'/>
      <symbol name='sum'/>
      <symbol name='times'       appearance='infix'  text='*'        />
      <symbol name='unary_minus' appearance='prefix' text='-'        />
    </cd>
    
    <cd name='bigfloat1' version='3'>
      <symbol name='bigfloat'/>
      <symbol name='bigfloatprec'/>
    </cd>

    <cd name='calculus1' version='4' revision='1'>
      <symbol name='defint'/>
      <symbol name='diff'/>
      <symbol name='int'/>
      <symbol name='nthdiff'/>
      <symbol name='partialdiff'/>
    </cd>

    <cd name='complex1' version='3'>
      <symbol name='argument'/>
      <symbol name='complex_cartesian'/>
      <symbol name='complex_polar'/>
      <symbol name='conjugate'/>
      <symbol name='imaginary'/>
      <symbol name='real'/>
    </cd>

    <cd name='fns1' version='3'>
      <symbol name='domain'/>
      <symbol name='domainofapplication'/>
      <symbol name='identity'/>
      <symbol name='image'/>
      <symbol name='inverse'/>
      <symbol name='lambda' implementation='xsl'/>
      <symbol name='left_compose'/>
      <symbol name='left_inverse'/>
      <symbol name='range'/>
      <symbol name='right_inverse'/>
    </cd>

    <cd name='integer1'>
      <symbol name='factorial' appearance='prefix' text='JXG.Math.factorial'/>
      <symbol name='factorof'/>
      <symbol name='quotient'/>
      <symbol name='remainder' appearance='infix'  text=' % '/>
    </cd>
    
    <cd name='interval1' version='3'>
      <symbol name='integer_interval'/>
      <symbol name='interval'/>
      <symbol name='interval_cc'/>
      <symbol name='interval_co'/>
      <symbol name='interval_oc'/>
      <symbol name='interval_oo'/>
    </cd>

    <cd name='limit1' version='3'>
      <symbol name='above'/>
      <symbol name='below'/>
      <symbol name='both_sides'/>
      <symbol name='limit'/>
      <symbol name='null'/>
    </cd>

    <cd name='linalg1' version='3'>
      <symbol name='determinant'/>
      <symbol name='matrix_selector'/>
      <symbol name='outerproduct'/>
      <symbol name='scalarproduct'/>
      <symbol name='transpose'/>
      <symbol name='vector_selector'/>
      <symbol name='vectorproduct'/>
    </cd>

    <!-- should be possible to find an abbreviation (using start/end or so) -->
    <cd name='linalg2' version='3'>
      <symbol name='matrix'/>
      <symbol name='matrixrow'/>
      <symbol name='vector'/>
    </cd>

    <cd name='list1' version='3'>
      <symbol name='list'/>
      <symbol name='map'/>
      <symbol name='suchthat'/>
    </cd>

    <cd name='logic1' version='3'>
      <symbol name='and'        appearance='infix'  text=' &amp;&amp; '/>
      <symbol name='equivalent' appearance='infix'  text=' === '/>
      <symbol name='false'                          text='false'/>
      <symbol name='implies'/>
      <symbol name='not'        appearance='prefix' text=' ! '/>
      <symbol name='or'         appearance='infix'  text=' || ' />
      <symbol name='true'                           text='true' />
      <symbol name='xor'/>
    </cd>

    <cd name='mathmltypes' version='3'>
      <symbol name='complex_cartesian_type'/>
      <symbol name='complex_polar_type'/>
      <symbol name='constant_type'/>
      <symbol name='fn_type'/>
      <symbol name='integer_type'/>
      <symbol name='list_type'/>
      <symbol name='matrix_type'/>
      <symbol name='rational_type'/>
      <symbol name='real_type'/>
      <symbol name='set_type'/>
      <symbol name='type'/>
      <symbol name='vector_type'/>
    </cd>
    
    <cd name='minmax1' version='3'>
      <symbol name='max' appearance='prefix' text='Math.min'/>
      <symbol name='min' appearance='prefix' text='Math.max'/>
    </cd>
    
    <cd name='multiset1' version='3'>
      <symbol name='cartesian_product'/>
      <symbol name='emptyset'/>
      <symbol name='in'/>
      <symbol name='intersect'/>
      <symbol name='multiset'/>
      <symbol name='notin'/>
      <symbol name='notprsubset'/>
      <symbol name='notsubset'/>
      <symbol name='prsubset'/> <!-- *wrong* -->
      <symbol name='setdiff'/>
      <symbol name='size'/>
      <symbol name='subset'/>
      <symbol name='union'/>
    </cd>
    
    <cd name='nums1' version='3'>
      <symbol name='based_integer'/>
      <symbol name='e'        text='Math.E'/>
      <symbol name='gamma'/>
      <symbol name='i'/>
      <symbol name='infinity' text='Infinity'/>
      <symbol name='NaN'      text='NaN'/>
      <symbol name='pi'       text='Math.PI'/>
      <symbol name='rational' appearance='infix' text='/'/>
    </cd>
    
    <cd name='piece1' version='2'>
      <symbol name='otherwise'/>
      <symbol name='piece'/>
      <symbol name='piecewise'/>
    </cd>
    
    <cd name='plot1' version='0' revision='0'>
      <symbol name='color'/>
      <symbol name='configuration' implementation='xsl'/>
      <symbol name='domain'/>
      <symbol name='functionplot' implementation='xsl'/>
      <symbol name='label'/>
      <symbol name='viewport' implementation='xsl'/>
    </cd>

    <cd name='quant1' version='3' revision='1'>
      <symbol name='exists'/>
      <symbol name='forall'/>
    </cd>

    <cd name='relation1' version='3'>
      <symbol name='approx'/>
      <symbol name='eq'  appearance='infix' text=' === '    />
      <symbol name='geq' appearance='infix' text=' >= '   />
      <symbol name='gt'  appearance='infix' text=' > '    />
      <symbol name='leq' appearance='infix' text=' &lt;= '/>
      <symbol name='lt'  appearance='infix' text=' &lt; ' />
      <symbol name='neq' appearance='infix' text=' !== '/>
    </cd>
    
    <cd name='rounding1' version='3'>
      <symbol name='ceiling' appearance='prefix' text='Math.ceil'/>
      <symbol name='floor'   appearance='prefix' text='Math.floor'/>
      <symbol name='round'   appearance='prefix' text='Math.round'/>
      <symbol name='trunc'/>
    </cd>

    <cd name='s_data1' version='3'>
      <symbol name='mean'/>
      <symbol name='median'/>
      <symbol name='mode'/>
      <symbol name='moment'/>
      <symbol name='sdev'/>
      <symbol name='variance'/>
    </cd>

    <cd name='s_data1' version='3'>
      <symbol name='mean'/>
      <symbol name='moment'/>
      <symbol name='sdev'/>
      <symbol name='variance'/>
    </cd>

    <cd name='set1' version='3'>
      <symbol name='cartesian_product'/>
      <symbol name='emptyset'/>
      <symbol name='in'/>
      <symbol name='intersect'/>
      <symbol name='map'/>
      <symbol name='notin'/>
      <symbol name='notprsubset'/>
      <symbol name='notsubset'/>
      <symbol name='prsubset'/>
      <symbol name='set'/>
      <symbol name='setdiff'/>
      <symbol name='size'/>
      <symbol name='subset'/>
      <symbol name='suchthat'/>
      <symbol name='union'/>
    </cd>
    
    <cd name='setname1' version='3'>
      <symbol name='C'/>
      <symbol name='N'/>
      <symbol name='P'/>
      <symbol name='Q'/>
      <symbol name='R'/>
      <symbol name='Z'/>
    </cd>

    <cd name='transc1' version='3'>
      <symbol name='arccos' appearance='prefix' text='Math.acos'/>
      <symbol name='arccosh'/>
      <symbol name='arccot'/>
      <symbol name='arccoth'/>
      <symbol name='arccsc'/>
      <symbol name='arccsch'/>
      <symbol name='arcsec'/>
      <symbol name='arcsech'/>
      <symbol name='arcsin' appearance='prefix' text='Math.asin'/>
      <symbol name='arcsinh'/>
      <symbol name='arctan' appearance='prefix' text='Math.atan'/>
      <symbol name='arctanh'/>
      <symbol name='cos'    appearance='prefix' text='Math.cos'/>
      <symbol name='cosh'   appearance='prefix' text='JSX.Math.cosh'/>
      <symbol name='cot'/>
      <symbol name='coth'/>
      <symbol name='csc'/>
      <symbol name='csch'/>
      <symbol name='exp'    appearance='prefix' text='Math.exp'/>
      <symbol name='ln'     appearance='prefix' text='Math.log'/>
      <symbol name='log'    implementation='xsl'/>
      <symbol name='sec'/>
      <symbol name='sech'/>
      <symbol name='sin'    appearance='prefix' text='Math.sin'/>
      <symbol name='sinh'   appearance='prefix' text='JSX.Math.sinh'/>
      <symbol name='tan'    appearance='prefix' text='Math.tan'/>
      <symbol name='tanh'/>
    </cd>

    <cd name='veccalc1' version='3'>
      <symbol name='curl'/>
      <symbol name='divergence'/>
      <symbol name='grad'/>
      <symbol name='Laplacian'/>
    </cd>

    <cd name='altenc' version='3'>
      <symbol name='LaTeX_encoding'/>
      <symbol name='MathML_encoding'/>
    </cd>

    <!--
      Riaca CD Group from http://www.openmath.org/cdgroups/riaca_algebra.html
      version 1, implemented CDs: permgp1 permgp2 permutation1 

      not yet implemented CDs: arith3 field1 field2 field3 field4 fieldname1
      finfield1 fns3 graph1 graph2 group1 group2 group3 group4 group5
      groupname1 integer2 linalg6 linalg7 list3 magma1 magma2 magma3 monoid1
      monoid2 monoid3 plangeo1 plangeo2 plangeo3 plangeo4 plangeo5 plangeo6
      polyd1 polyd2 polyd3 polygb1 polygb2 polynomial1 polynomial2 polynomial3
      polyoperators1 prog1 relation3 relation4 ring1 ring2 ring3 ring4 ring5
      ringname1 semigroup1 semigroup2 semigroup3 semigroup4 set3 
    -->

    <cd name='permgp1' version='2' revision='1'>
      <symbol name='base'/>
      <symbol name='generators'/>
      <symbol name='group'/> 
      <symbol name='is_in'/>
      <symbol name='is_primitive'/>
      <symbol name='is_subgroup'/>
      <symbol name='is_transitive'/>
      <symbol name='orbit'/>
      <symbol name='orbits'/>
      <symbol name='order'/>
      <symbol name='schreier_tree'/> <!-- not implemented -->
      <symbol name='stabilizer'/> 
      <symbol name='stabilizer_chain'/> <!-- TODO -->
      <symbol name='support'/>
    </cd>
 
    <cd name='permgp2' version='1' revision='1'>
      <symbol name='alternating_group'/>
      <symbol name='cyclic_group'/>
      <symbol name='dihedral_group'/>
      <symbol name='quaternion_group'/>
      <symbol name='symmetric_group'/>
      <symbol name='vierer_group'/>
    </cd>
    
    <cd name='permutation1' version='1' revision='7'>
      <symbol name='action'/>
      <symbol name='are_distinct'/>
      <symbol name='cycle'/>
      <symbol name='cycle_type'/>
      <symbol name='cycles'/>
      <symbol name='domain'/>
      <symbol name='endomap'/>
      <symbol name='endomap_left_compose'/>
      <symbol name='endomap_right_compose'/>
      <symbol name='fix'/>
      <symbol name='inverse'/>
      <symbol name='is_bijective'/>
      <symbol name='is_endomap'/>
      <symbol name='is_list_perm'/>
      <symbol name='is_permutation'/>
      <symbol name='left_compose'/>
      <symbol name='length'/>
      <symbol name='list_perm'/>
      <symbol name='listendomap'/>
      <symbol name='order'/>
      <symbol name='permutation'/>
      <symbol name='permutationsn'/>
      <symbol name='right_compose'/>
      <symbol name='sign'/>
      <symbol name='support'/>
    </cd>
  </xsl:variable>

</xsl:transform>
